@@ -6,22 +6,22 @@ from ._constants import MAX_DIRNAME_LEN, MAX_FILENAME_LEN
 
 
 def sanitize_filepath(filepath):
-    """ sanitize a filepath """
+    """sanitize a filepath"""
     return pathvalidate.sanitize_filepath(filepath, platform="macos")
 
 
 def is_valid_filepath(filepath):
-    """ returns True if a filepath is valid otherwise False """
+    """returns True if a filepath is valid otherwise False"""
     return pathvalidate.is_valid_filepath(filepath, platform="macos")
 
 
 def sanitize_filename(filename, replacement=":"):
-    """ replace any illegal characters in a filename and truncate filename if needed
+    """replace any illegal characters in a filename and truncate filename if needed
 
     Args:
         filename: str, filename to sanitze
         replacement: str, value to replace any illegal characters with; default = ":"
-    
+
     Returns:
         filename with any illegal characters replaced by replacement and truncated if necessary
     """
@@ -46,12 +46,12 @@ def sanitize_filename(filename, replacement=":"):
 
 
 def sanitize_dirname(dirname, replacement=":"):
-    """ replace any illegal characters in a directory name and truncate directory name if needed
+    """replace any illegal characters in a directory name and truncate directory name if needed
 
     Args:
-        dirname: str, directory name to sanitze
-        replacement: str, value to replace any illegal characters with; default = ":"
-    
+        dirname: str, directory name to sanitize
+        replacement: str, value to replace any illegal characters with; default = ":"; if None, no replacement occurs
+
     Returns:
         dirname with any illegal characters replaced by replacement and truncated if necessary
     """
@@ -61,19 +61,20 @@ def sanitize_dirname(dirname, replacement=":"):
 
 
 def sanitize_pathpart(pathpart, replacement=":"):
-    """ replace any illegal characters in a path part (either directory or filename without extension) and truncate name if needed
+    """replace any illegal characters in a path part (either directory or filename without extension) and truncate name if needed
 
     Args:
-        pathpart: str, path part to sanitze
-        replacement: str, value to replace any illegal characters with; default = ":"
-    
+        pathpart: str, path part to sanitize
+        replacement: str, value to replace any illegal characters with; default = ":"; if None, no replacement occurs
+
     Returns:
         pathpart with any illegal characters replaced by replacement and truncated if necessary
     """
     if pathpart:
-        pathpart = pathpart.replace("/", replacement)
+        pathpart = (
+            pathpart.replace("/", replacement) if replacement is not None else pathpart
+        )
         if len(pathpart) > MAX_DIRNAME_LEN:
             drop = len(pathpart) - MAX_DIRNAME_LEN
             pathpart = pathpart[:-drop]
     return pathpart
-
